@@ -33,10 +33,10 @@ while {$i < $argc} {
     switch -exact -- [lindex $argv $i] {
 	- {}
 	-- {}
-	-u {incr i; lappend "auth_args -user [lindex $argv $i] "}
-	-user {incr i; lappend "auth_args -user [lindex $argv $i] "}
-	-p {incr i; lappend "auth_args -protection [lindex $argv $i] "}
-	-protection {incr i; lappend "auth_args -protection [lindex $argv $i]" }
+	-u {incr i; lappend auth_args -user [lindex $argv $i] }
+	-user {incr i; lappend auth_args -user [lindex $argv $i] }
+	-p {incr i; lappend auth_args -protection [lindex $argv $i] }
+	-protection {incr i; lappend auth_args -protection [lindex $argv $i] }
 	default {lappend conn_args [lindex $argv $i]}
     }
     incr i
