@@ -1,15 +1,29 @@
 /* config.c -- Configuration routines
- *
- * Copyright 1996, Carnegie Mellon University.  All Rights Reserved.
- * 
- * This software is made available for academic and research
- * purposes only.  No commercial license is hereby granted.
- * Copying and other reproduction is authorized only for research,
- * education, and other non-commercial purposes.  No warranties,
- * either expressed or implied, are made regarding the operation,
- * use, or results of the software.  Such a release does not permit
- * use of the code for commercial purposes or benefits by anyone
- * without specific, additional permission by the owner of the code.
+ $Id: config.c,v 1.17 1998/05/15 21:48:14 neplokh Exp $
+ 
+ # Copyright 1998 Carnegie Mellon University
+ # 
+ # No warranties, either expressed or implied, are made regarding the
+ # operation, use, or results of the software.
+ #
+ # Permission to use, copy, modify and distribute this software and its
+ # documentation is hereby granted for non-commercial purposes only
+ # provided that this copyright notice appears in all copies and in
+ # supporting documentation.
+ #
+ # Permission is also granted to Internet Service Providers and others
+ # entities to use the software for internal purposes.
+ #
+ # The distribution, modification or sale of a product which uses or is
+ # based on the software, in whole or in part, for commercial purposes or
+ # benefits requires specific, additional permission from:
+ #
+ #  Office of Technology Transfer
+ #  Carnegie Mellon University
+ #  5000 Forbes Avenue
+ #  Pittsburgh, PA  15213-3890
+ #  (412) 268-4387, fax: (412) 268-7395
+ #  tech-transfer@andrew.cmu.edu
  *
  */
 #include <stdio.h>
@@ -24,6 +38,18 @@
 extern int errno;
 
 #define CONFIG_FILENAME "/etc/imapd.conf"
+/* You'd think this'd be EX_CONFIG, but you'd be wrong.
+   If it's EX_CONFIG then sendmail's result is to fatally reject the
+   message; this isn't desireable, we just want to fail the message in a
+   more limited case.
+
+   We had a situation where someone changed imapd.conf and made it
+   unreadable by Cyrus.  In 13 seconds, 4 messages were rejected, so I
+   changed the code.
+   
+   XXX hopefully sendmail is the only meaningful place where this matters.
+   */
+#define CONFIG_EXIT_STATUS EX_TEMPFAIL
 
 struct configlist {
     char *key;
@@ -57,7 +83,7 @@ const char *ident;
     config_dir = config_getstring("configdirectory", (char *)0);
     if (!config_dir) {
 	fatal("configdirectory option not specified in configuration file",
-	      EX_CONFIG);
+	      CONFIG_EXIT_STATUS);
     }
 
     mboxlist_checkconfig();
@@ -67,13 +93,13 @@ const char *ident;
     for (p = (char *)config_defpartition; *p; p++) {
 	if (!isalnum(*p))
 	  fatal("defaultpartition option contains non-alphanumeric character",
-		EX_CONFIG);
+		CONFIG_EXIT_STATUS);
 	if (isupper(*p)) *p = tolower(*p);
     }
     if (!config_partitiondir(config_defpartition)) {
 	sprintf(buf, "partition-%s option not specified in configuration file",
 		config_defpartition);
-	fatal(buf, EX_CONFIG);
+	fatal(buf, CONFIG_EXIT_STATUS);
     }
 
     /* Look up umask */
@@ -160,7 +186,7 @@ config_read()
     if (!infile) {
 	sprintf(buf, "can't open configuration file %s: %s", CONFIG_FILENAME,
 		error_message(errno));
-	fatal(buf, EX_CONFIG);
+	fatal(buf, CONFIG_EXIT_STATUS);
     }
     
     while (fgets(buf, sizeof(buf), infile)) {
@@ -179,7 +205,7 @@ config_read()
 	    sprintf(buf,
 		    "invalid option name on line %d of configuration file",
 		    lineno);
-	    fatal(buf, EX_CONFIG);
+	    fatal(buf, CONFIG_EXIT_STATUS);
 	}
 	*p++ = '\0';
 
@@ -188,7 +214,7 @@ config_read()
 	if (!*p) {
 	    sprintf(buf, "empty option value on line %d of configuration file",
 		    lineno);
-	    fatal(buf, EX_CONFIG);
+	    fatal(buf, CONFIG_EXIT_STATUS);
 	}
 
 	if (nconfiglist == alloced) {
