@@ -1,34 +1,37 @@
 /* pop3d.c -- POP3 server protocol parsing
- $Id: pop3d.c,v 1.35 1998/05/15 21:49:36 neplokh Exp $
- 
- # Copyright 1998 Carnegie Mellon University
- # 
- # No warranties, either expressed or implied, are made regarding the
- # operation, use, or results of the software.
- #
- # Permission to use, copy, modify and distribute this software and its
- # documentation is hereby granted for non-commercial purposes only
- # provided that this copyright notice appears in all copies and in
- # supporting documentation.
- #
- # Permission is also granted to Internet Service Providers and others
- # entities to use the software for internal purposes.
- #
- # The distribution, modification or sale of a product which uses or is
- # based on the software, in whole or in part, for commercial purposes or
- # benefits requires specific, additional permission from:
- #
- #  Office of Technology Transfer
- #  Carnegie Mellon University
- #  5000 Forbes Avenue
- #  Pittsburgh, PA  15213-3890
- #  (412) 268-4387, fax: (412) 268-7395
- #  tech-transfer@andrew.cmu.edu
  *
+ * Copyright 1998 Carnegie Mellon University
+ * 
+ * No warranties, either expressed or implied, are made regarding the
+ * operation, use, or results of the software.
+ *
+ * Permission to use, copy, modify and distribute this software and its
+ * documentation is hereby granted for non-commercial purposes only
+ * provided that this copyright notice appears in all copies and in
+ * supporting documentation.
+ *
+ * Permission is also granted to Internet Service Providers and others
+ * entities to use the software for internal purposes.
+ *
+ * The distribution, modification or sale of a product which uses or is
+ * based on the software, in whole or in part, for commercial purposes or
+ * benefits requires specific, additional permission from:
+ *
+ *  Office of Technology Transfer
+ *  Carnegie Mellon University
+ *  5000 Forbes Avenue
+ *  Pittsburgh, PA  15213-3890
+ *  (412) 268-4387, fax: (412) 268-7395
+ *  tech-transfer@andrew.cmu.edu
+ */
+
+/*
+ * $Id: pop3d.c,v 1.40 1998/12/02 18:54:46 tjs Exp $
  */
 
 #include <stdio.h>
 #include <string.h>
+#include <fcntl.h>
 #include <time.h>
 #include <signal.h>
 #include <sys/types.h>
@@ -87,6 +90,11 @@ static struct mailbox mboxstruct;
 
 static int expungedeleted();
 
+static void cmd_auth();
+static void cmd_capa();
+static void cmd_pass();
+static void cmd_user();
+
 main(argc, argv, envp)
 int argc;
 char **argv;
@@ -235,7 +243,7 @@ kpop()
     strcpy(instance, "*");
     r = krb_recvauth(0L, 0, &ticket, "pop", instance,
 		     &popd_remoteaddr, (struct sockaddr_in *) NULL,
-		     &kdata, srvtab, schedule, version);
+		     &kdata, (char*) srvtab, schedule, version);
     
     if (r) {
 	prot_printf(popd_out, "-ERR Kerberos authentication failure: %s\r\n",
@@ -317,24 +325,20 @@ cmdloop()
 	    }
 	    else prot_printf(popd_out, "-ERR Unexpected extra argument\r\n");
 	}
-	if (!popd_mailbox) {
+	else if (!strcmp(inputbuf, "capa")) {
+	    if (arg) {
+		prot_printf(popd_out, "-ERR Unexpected extra argument\r\n");
+	    } else {
+		cmd_capa();
+	    }
+	}
+	else if (!popd_mailbox) {
 	    if (!strcmp(inputbuf, "user")) {
-		if (popd_userid) {
-		    prot_printf(popd_out, "-ERR Must give PASS command\r\n");
-		}
-		else if (!arg) {
+		if (!arg) {
 		    prot_printf(popd_out, "-ERR Missing argument\r\n");
 		}
-		else if (!(p = auth_canonifyid(arg)) ||
-			 strchr(p, '.') || strlen(p) + 6 > MAX_MAILBOX_PATH) {
-		    prot_printf(popd_out, "-ERR Invalid user\r\n");
-		    syslog(LOG_NOTICE,
-			   "badlogin: %s plaintext %s invalid user",
-			   popd_clienthost, beautify_string(arg));
-		}
 		else {
-		    popd_userid = xstrdup(p);
-		    prot_printf(popd_out, "+OK Name is a valid mailbox\r\n");
+		    cmd_user(arg);
 		}
 	    }
 	    else if (!strcmp(inputbuf, "pass")) {
@@ -502,7 +506,47 @@ cmdloop()
     }		
 }
 
-cmd_pass(pass)
+void
+cmd_user(user)
+char *user;
+{
+    int fd;
+    struct protstream *shutdown_in;
+    char buf[1024];
+    char *p;
+    char shutdownfilename[1024];
+
+    if (popd_userid) {
+	prot_printf(popd_out, "-ERR Must give PASS command\r\n");
+	return;
+    }
+
+    sprintf(shutdownfilename, "%s/msg/shutdown", config_dir);
+    if ((fd = open(shutdownfilename, O_RDONLY, 0)) != -1) {
+	shutdown_in = prot_new(fd, 0);
+	prot_fgets(buf, sizeof(buf), shutdown_in);
+	if (p = strchr(buf, '\r')) *p = 0;
+	if (p = strchr(buf, '\n')) *p = 0;
+
+	for(p = buf; *p == '['; p++); /* can't have [ be first char */
+	prot_printf(popd_out, "-ERR %s\r\n", p);
+	prot_flush(popd_out);
+	shut_down(0);
+    }
+    else if (!(p = auth_canonifyid(user)) ||
+	       strchr(p, '.') || strlen(p) + 6 > MAX_MAILBOX_PATH) {
+	prot_printf(popd_out, "-ERR Invalid user\r\n");
+	syslog(LOG_NOTICE,
+	       "badlogin: %s plaintext %s invalid user",
+	       popd_clienthost, beautify_string(user));
+    }
+    else {
+	popd_userid = xstrdup(p);
+	prot_printf(popd_out, "+OK Name is a valid mailbox\r\n");
+    }
+}
+
+void cmd_pass(pass)
 char *pass;
 {
     char *reply = 0;
@@ -569,6 +613,58 @@ char *pass;
     openinbox();
 }
 
+/* Handle the POP3 Extension extension.
+ */
+void
+cmd_capa()
+{
+    int i;
+    int minpoll = config_getint("popminpoll", 0) * 60;
+    int expire = config_getint("popexpiretime", -1);
+    const char *capabilities, *next_capabilities;
+
+    prot_printf(popd_out, "+OK List of capabilities follows\r\n");
+
+    /* SASL special case: print SASL, then a list of supported capabilities
+       (parsed from the IMAP-style login_capabilities function, then a CRLF */
+    prot_printf(popd_out, "SASL"); /* no \r\n */
+    next_capabilities = login_capabilities();
+    while (next_capabilities[0]) {
+	capabilities = next_capabilities;
+	next_capabilities = strchr(capabilities+1, ' ');
+	if (!next_capabilities) {
+	    next_capabilities = capabilities + strlen(capabilities);
+	}
+	if (!strncmp(capabilities, " AUTH=", 6)) {
+	    capabilities += 6;
+	    prot_putc(' ', popd_out);
+	    prot_write(popd_out, capabilities,
+		       next_capabilities - capabilities);
+	}
+    }
+    prot_printf(popd_out, "\r\n");
+
+    if (expire < 0) {
+	prot_printf(popd_out, "EXPIRE NEVER\r\n");
+    } else {
+	prot_printf(popd_out, "EXPIRE %d\r\n", expire);
+    }
+
+    prot_printf(popd_out, "LOGIN-DELAY %d\r\n", minpoll);
+    prot_printf(popd_out, "TOP\r\n");
+    prot_printf(popd_out, "UIDL\r\n");
+    prot_printf(popd_out, "PIPELINE\r\n");
+    prot_printf(popd_out, "USER\r\n");
+    
+    prot_printf(popd_out,
+		"IMPLEMENTATION Cyrus POP3 server %s\r\n",
+		CYRUS_VERSION);
+
+    prot_printf(popd_out, ".\r\n");
+    prot_flush(popd_out);
+}
+
+void
 cmd_auth(authtype)
 char *authtype;
 {
@@ -731,14 +827,14 @@ int openinbox()
 	mailbox_close(&mboxstruct);
 	free(popd_userid);
 	popd_userid = 0;
-	prot_printf(popd_out, "-ERR Unable to lock maildrop\r\n");
+	prot_printf(popd_out, "-ERR [IN-USE] Unable to lock maildrop\r\n");
 	return 1;
     }
 
     if ((minpoll = config_getint("popminpoll", 0)) &&
 	mboxstruct.pop3_last_login + 60*minpoll > popd_login_time) {
 	prot_printf(popd_out,
-		    "-ERR Logins must be at least %d minute%s apart\r\n",
+	    "-ERR [LOGIN-DELAY] Logins must be at least %d minute%s apart\r\n",
 		    minpoll, minpoll > 1 ? "s" : "");
 	if (!mailbox_lock_index(&mboxstruct)) {
 	    mboxstruct.pop3_last_login = popd_login_time;
