@@ -1,15 +1,25 @@
 /* auth_krb.c -- Kerberos authorization
- *
- * Copyright 1996, Carnegie Mellon University.  All Rights Reserved.
- * 
- * This software is made available for academic and research
- * purposes only.  No commercial license is hereby granted.
- * Copying and other reproduction is authorized only for research,
- * education, and other non-commercial purposes.  No warranties,
- * either expressed or implied, are made regarding the operation,
- * use, or results of the software.  Such a release does not permit
- * use of the code for commercial purposes or benefits by anyone
- * without specific, additional permission by the owner of the code.
+ $Id: auth_krb.c,v 1.27 1998/05/15 21:50:43 neplokh Exp $
+ 
+ #        Copyright 1998 by Carnegie Mellon University
+ #
+ #                      All Rights Reserved
+ #
+ # Permission to use, copy, modify, and distribute this software and its
+ # documentation for any purpose and without fee is hereby granted,
+ # provided that the above copyright notice appear in all copies and that
+ # both that copyright notice and this permission notice appear in
+ # supporting documentation, and that the name of CMU not be
+ # used in advertising or publicity pertaining to distribution of the
+ # software without specific, written prior permission.
+ #
+ # CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
+ # ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
+ # CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
+ # ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ # WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ # ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
+ # SOFTWARE.
  *
  */
 
@@ -17,6 +27,14 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
+#include <sys/types.h>
+
+#include <krb.h>
+#ifdef HAVE_DB_185_H
+#include <db_185.h>
+#else
+#include <db.h>
+#endif
 #include <krb.h>
 
 #include "auth.h"
@@ -175,7 +193,7 @@ const char *real_realm;
 		    strcmp(lrealm, realm) == 0) {
 		    *realm = 0;
 		}
-		else if (krb_get_krbhst(krbhst, realm, 0)) {
+		else if (krb_get_krbhst(krbhst, realm, 1)) {
 		    return 0;		/* Unknown realm */
 		}
 	    }
@@ -237,7 +255,7 @@ const char *identifier;
 	    strcmp(lrealm, realm) == 0) {
 	    *realm = 0;
 	}
-	else if (krb_get_krbhst(krbhst, realm, 0)) {
+	else if (krb_get_krbhst(krbhst, realm, 1)) {
 	    return 0;		/* Unknown realm */
 	}
     }
