@@ -1,29 +1,31 @@
 /* glob.c -- fast globbing routine using '*', '%', and '?'
- $Id: glob.c,v 1.15 1998/05/15 21:51:18 neplokh Exp $
- 
- #        Copyright 1998 by Carnegie Mellon University
- #
- #                      All Rights Reserved
- #
- # Permission to use, copy, modify, and distribute this software and its
- # documentation for any purpose and without fee is hereby granted,
- # provided that the above copyright notice appear in all copies and that
- # both that copyright notice and this permission notice appear in
- # supporting documentation, and that the name of CMU not be
- # used in advertising or publicity pertaining to distribution of the
- # software without specific, written prior permission.
- #
- # CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
- # ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
- # CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
- # ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
- # WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
- # ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
- # SOFTWARE.
+ *
+ *        Copyright 1998 by Carnegie Mellon University
+ *
+ *                      All Rights Reserved
+ *
+ * Permission to use, copy, modify, and distribute this software and its
+ * documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and that
+ * both that copyright notice and this permission notice appear in
+ * supporting documentation, and that the name of CMU not be
+ * used in advertising or publicity pertaining to distribution of the
+ * software without specific, written prior permission.
+ *
+ * CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
+ * ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
+ * CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
+ * ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
+ * SOFTWARE.
  *
  * Author: Chris Newman
  * Start Date: 4/5/93
  */
+/*
+ * $Id: glob.c,v 1.17 1998/06/10 22:18:37 tjs Exp $
+ */
 
 #include <ctype.h>
 #include <stdio.h>
@@ -45,7 +47,10 @@ static char inbox[] = "INBOX";
  *   4) '*' eats all '*'s and '%'s connected by any wildcard
  *   5) '%' eats all adjacent '%'s
  */
-glob *glob_init_suppress P((const char *str, int flags, const char *suppress))
+glob *glob_init_suppress (str, flags, suppress)
+    const char *str;
+    int flags;
+    const char *suppress;
 {
     glob *g;
     char *dst;
@@ -162,7 +167,8 @@ glob *glob_init_suppress P((const char *str, int flags, const char *suppress))
 
 /* free a glob structure
  */
-void glob_free P((glob **g))
+void glob_free (g)
+    glob **g;
 {
     fs_give((void **) g);
 }
@@ -175,7 +181,11 @@ void glob_free P((glob **g))
  *            set to return value + 1 on partial match, otherwise -1
  *            if NULL, partial matches not allowed
  */
-int glob_test P((glob *g, const char *ptr, long int len, long int *min))
+int glob_test (g, ptr, len, min)
+    glob* g;
+    const char* ptr;
+    long int len;
+    long int *min;
 {
     const char *gptr, *pend;	/* glob pointer, end of ptr string */
     const char *gstar, *pstar;	/* pointers for '*' patterns */
@@ -373,7 +383,9 @@ int glob_test P((glob *g, const char *ptr, long int len, long int *min))
 }
 
 #ifdef TEST_GLOB
-int main P((int argc, char **argv))
+int main (argc, argv)
+    int argc;
+    char* argv[];
 {
     glob *g = glob_init_suppress(argv[1], GLOB_INBOXCASE|GLOB_HIERARCHY,
 				 "user.nifty");
